package Simple;

## no critic

use 5.008;
use strict;
use warnings;
use Wx ':everything';
use Wx::Html ();
use Wx::Locale ();

our $VERSION = '0.01';
our @ISA     = 'Wx::App';

1;
